SEP.summary <-
function (..., conf.level = 0.95) 
{
	# Modified in 360_ForSubmissSalsaMS
	# (to accept one row SEPs)
	# CORRECTED in 357_salsa0.2
	# To avoid error when constant SEPs are pass!
    seps <- list(...)
    n.seps <- length(seps)
    g.seps <- paste("g", c(1:n.seps), sep = ".")
    names(seps) <- g.seps
    for (i in 1:n.seps) {
        if (prod(names(SEP) == names(seps[[i]])) * (class(seps[[i]]) == 
            "data.frame") != 1) 
            stop(paste("\nArgument number", i, "is not a valid SEP data.frame!"))
        if (nrow(seps[[i]]) < 2) {
        	# A SEP with only one row was found
        		warning(paste("\nArgument number", i, "is a SEP with only one row. CIs for that SEP are not valid (values set equal to the mean)!"))
        } 
    }
    general <- data.frame(n.rows = unlist(lapply(seps, nrow)), 
        n.ids = rep(NA, n.seps), n.acc = rep(NA, n.seps), n.type = rep(NA, 
            n.seps), n.mod = rep(NA, n.seps), mean.TimeMaxExp = rep(NA, 
            n.seps), LL.TimeMaxExp = rep(NA, n.seps), UL.TimeMaxExp = rep(NA, 
            n.seps), row.names = names(seps))
    time.means <- data.frame(matrix(NA, nrow = n.seps, ncol = 7, 
        dimnames = list(c(g.seps), paste("m.T", seq(0, 60, 10), 
            sep = ""))))
    LL.time.means <- data.frame(matrix(NA, nrow = n.seps, ncol = 7, 
        dimnames = list(c(g.seps), paste("LL.m.T", seq(0, 60, 
            10), sep = ""))))
    UL.time.means <- data.frame(matrix(NA, nrow = n.seps, ncol = 7, 
        dimnames = list(c(g.seps), paste("UL.m.T", seq(0, 60, 
            10), sep = ""))))
    temp.sd <- rep(0, n.seps) # Temporal values of Standard Deviations
    for (i in 1:n.seps) {
        time.means[i, 1:7] <- apply(seps[[i]][, 6:12], 2, mean)
        general$n.ids[i] <- length(unique(seps[[i]]$id))
        general$n.acc[i] <- length(unique(seps[[i]]$acc.key))
        general$n.type[i] <- length(unique(seps[[i]]$acc.type))
        general$n.mod[i] <- length(unique(seps[[i]]$model))
        general$mean.TimeMaxExp[i] <- mean(seps[[i]]$TimeMaxExp)
		if(general$n.rows[i]>1){
			temp.sd[i] <- sd(seps[[i]]$TimeMaxExp)
		}
        if (temp.sd[i] > 0) {
            temp <- t.test(seps[[i]]$TimeMaxExp, conf.level = conf.level)
            general$LL.TimeMaxExp[i] <- temp$conf.int[1]
            general$UL.TimeMaxExp[i] <- temp$conf.int[2]
        }
        else {
            general$LL.TimeMaxExp[i] <- general$mean.TimeMaxExp[i]
            general$UL.TimeMaxExp[i] <- general$mean.TimeMaxExp[i]
        }
        for (j in 6:12) {
        	# Here goes the correction:
#        	if(sd(seps[[i]][, j])<1e-5){
			if(temp.sd[i]<1e-5){
        		LL.time.means[i, j - 5] <- time.means[i, j - 5]
        		UL.time.means[i, j - 5] <- time.means[i, j - 5] 
        	} else {
            temp <- t.test(seps[[i]][, j], conf.level = conf.level)
            LL.time.means[i, j - 5] <- temp$conf.int[1]
            UL.time.means[i, j - 5] <- temp$conf.int[2]        		
        	}
        }
    }
    res <- list(general, time.means, LL.time.means, UL.time.means)
    names(res) <- c("general", "time.means", "LL.time.means", 
        "UL.time.means")
    res
}
