SEPs.plot <-
function (seps, colors="black", lwd = 2, conf.level = 0.95, CIs.sep = 0.5) 
{
	# Modified in "360_ForSubmissSalsaMS"
	#    for cases of SEPs. In that case "warning" are suppressed!
	defaultW <- getOption("warn")
	options(warn = -1)

	# Corrected in "357_salsa0.2" for the cases of UNIFORM SEPs
	# (that does not have positive standard deviations)
    if ((class(seps) != "data.frame") & (class(seps) != "list")) 
        stop("Parameter seps must be a single SEP (data.frame) or a list of SEPs!")
    if (class(seps) == "data.frame") {
        sep.sum <- SEP.summary(seps, conf.level = conf.level)
        if (length(colors) > 1) 
            stop("\ncolors must have a single value!")
        temp <- unlist(sep.sum[2:4])
        the.lim <- c(min(temp), max(temp))
        plot(DAA, sep.sum$time.means, xlab = "Time (DAA)", ylab = "Standardized Expression", 
            ylim = the.lim, type = "b", col = colors, lwd = lwd)
        segments(x0 = DAA, x1 = DAA, y0 = unlist(sep.sum$LL.time.means), 
            y1 = unlist(sep.sum$UL.time.means), col = colors)
    }
    else {
        n.seps <- length(seps)
        if (length(colors) < n.seps) 
            stop("You must provide as many colors as SEPs do you have in first parameter (seps)")
        all.sep.sum <- vector("list", n.seps)
        for (i in 1:n.seps) {
            all.sep.sum[[i]] <- SEP.summary(seps[[i]], conf.level = conf.level)
            if (i == 1) {
                for.lim <- unlist(all.sep.sum[[i]][2:4])
            }
            else {
                for.lim <- c(for.lim, unlist(all.sep.sum[[i]][2:4]))
            }
        }
        the.lim <- c(min(for.lim), max(for.lim))
        the.inc <- (-CIs.sep) * (n.seps/2)
        the.x <- DAA + the.inc
        plot(the.x, all.sep.sum[[1]]$time.means, xlab = "Time (DAA)", 
            ylab = "Standardized Expression", ylim = the.lim, 
            type = "b", col = colors[1], lwd = lwd)
        segments(x0 = the.x, x1 = the.x, y0 = unlist(all.sep.sum[[1]]$LL.time.means), 
            y1 = unlist(all.sep.sum[[1]]$UL.time.means), col = colors[1])
        for (i in 2:n.seps) {
            the.x <- the.x + CIs.sep
            points(the.x, all.sep.sum[[i]]$time.means, type = "b", 
                col = colors[i], lwd = lwd)
            segments(x0 = the.x, x1 = the.x, y0 = unlist(all.sep.sum[[i]]$LL.time.means), 
                y1 = unlist(all.sep.sum[[i]]$UL.time.means), 
                col = colors[i])
        }
    }
    options(warn = defaultW)
}
