analyze.2.SEPs <-
function (sep1, sep2, conf.level = 0.95, do.print = TRUE) 
{
    # analyze.2.SEPs
    # SEE 356_UsingSALSA [Tue Oct 20 19:18:55 2020]
    
    # Validate input
    if(prod(names(SEP)==names(sep1))*(class(sep1)=="data.frame") != 1) stop("\nsep1 is not a valid SEP data.frame!")
	if(prod(names(SEP)==names(sep2))*(class(sep2)=="data.frame") != 1) stop("\nsep2 is not a valid SEP data.frame!")
	
	# Only mean distances per time
	sep1 <- sep1[, 6:12]
    sep2 <- sep2[, 6:12]
    n.seps <- c(nrow(sep1), nrow(sep2))
    
    # Impossible cases and warnings
    if (n.seps[1] < 2) 
        stop("\nNumber of SEPs in sep1 < 2.\nAnalysis is not possible.")
    if (n.seps[2] < 2) 
        stop("\nNumber of SEPs in sep2 < 2.\nAnalysis is not possible.")
    if (n.seps[1] < 3) 
        warning(paste("\nNumber of SEPs in sep1 =", n.seps[1], 
            "distances within group1 will be estimated from only", 
            n.seps[1] * (n.seps[1] - 1)/2, "values."))
    if (n.seps[2] < 3) 
        warning(paste("\nNumber of SEPs in sep2 =", n.seps[2], 
            "distances within group1 will be estimated from only", 
            n.seps[2] * (n.seps[2] - 1)/2, "values."))
            
    # Calculate the distances within each group and
    # collapse them as a single vector
    d.wit <- c(as.vector(dist(sep1, method = "euclidean")), as.vector(dist(sep2, method = "euclidean")))
    d.bet <- rep(NA, n.seps[1] * n.seps[2])
    k <- 0
    for (i in 1:n.seps[1]) {
        for (j in 1:n.seps[2]) {
            k <- k + 1
            d.bet[k] <- sqrt(sum((sep1[i, ] - sep2[j, ])^2))
        }
    }
    d.test <- t.test(x = d.bet, y = d.wit, alternative = "greater", 
        conf.level = conf.level)
    #d.test.p <- d.test # For printing
    
    # format the result to be invivible returned
    # 1-n.sep1, 2-n.sep2, 3,-t.value, 4-df, 5-p-value, 6-conf.level
    # 7-L.CL, 8-mean.dis.bet, 9-mean.dis.wit 
    res <- c(n.seps, d.test[[1]], d.test[[2]], d.test[[3]], conf.level, d.test[[4]][1], d.test[[5]])
    names(res) <- c("n.sep1", "n.sep2", "t.value", "df", "p-value", "conf.level", "L.CL", "mean.dis.bet", "mean.dis.wit")
    
    if(do.print){
    	cat("Number of SEPs in sep1:", n.seps[1], ". Number of SEPs in sep2:", n.seps[2], "\nTest of Euclidean distances between and within SEPs:\n")
    	print(d.test)
    }
    invisible(res)
}
