analyze.GO <-
function(ids, aspect = "BP", aspect.id = 494, print.all = TRUE){
	# analyze.GO; SEE: 355_Salsa
	
	# analyze.GO [edited from BP.analysis.ById ]
	# SEE: 342_GO-KEGGfun
	# "/Users/OMV/Proyectos/Chile/2020/7_Julio/Rstuff342"
	
	# Performs an "enrichment" analysis for a set of genes.
	
	# ids - Identifiers of the "target" genes.
	# aspect - GO aspect: "BP", "CC" or "MF" in data all.GO$aspect
	# aspect.id - Identifier of the aspect all.GO$aspect.id
	# The description of all.GO$aspect.id in all.GO$GO.desc
	# print.all - Want to print the details of the analysis?
	
	# NEEDS: GO.annot, all.GO and functions get.mat.from.ids, expected
	
	if(!is.element(aspect, c("BP", "CC", "MF"))) stop('\"aspect\" must be \"BP\", \"CC\" or \"MF\"')
	
	# Get aspect.desc
	desc <- all.GO$GO.desc[(all.GO$aspect==aspect)&(all.GO$aspect.id==aspect.id)]
	
	# Get the table
	temp.t <- get.mat.from.ids(s.t = ids, aspect = aspect, aspect.id = aspect.id)

	obs <- as.vector(temp.t)
	names(obs) <- c("AnnTarg", "NotAnnTarg", "AnnNotTarg", "NotAnnNotTarg")
	
	# Performs Fisher exac test
	temp.ft <- fisher.test(temp.t)
	
	# Estimated odds ratio from the table.
	temp.od <- (temp.t[1,1]*temp.t[2,2])/(temp.t[2,1]*temp.t[1,2]) 
	
	if(print.all){
		cat("Aspect: \"", aspect, "\"; Aspect id = ", aspect.id, "\nDescription: \"", desc, "\"\nNumber of ids in target = ", length(ids), "\n\nObserved matrix:\n", sep='')
		print(temp.t)
		
		cat("\nRounded expected values:\n")
		print(round(expected(temp.t), 2))
		cat("\nEstimated odds ratio from the table = ", temp.od, "\n", sep='')
		print(temp.ft)
	} # Finished printing
	
	# Formatting the output
	res <- data.frame(aspect, aspect.id, desc, odds=temp.od, P=temp.ft$p.value, t(obs), stringsAsFactors=FALSE) 
	invisible(res) # Regresa de manera invisible el resultado. 
}
