analyze.all.GO <-
function (ids, aspect = "BP", only.FDR.le = NULL) 
{
	# analyze.all.GO
	# Analyzes a group of ids for all terms in one aspect.
	# SEE: 357_salsa0.2
	# Depends on "analyze.GO"
    if (!is.element(aspect, c("BP", "CC", "MF"))) 
        stop("\"aspect\" must be \"BP\", \"CC\" or \"MF\"!")
    # only.FDR.le : Give only cases where Q is less of equal
    # that value
    if(!is.null(only.FDR.le)){
    		if(class(only.FDR.le)!="numeric") stop("Parameter only.FDR.le must be numeric!")
    }
        
    aspect.ids <- sort(unique(all.GO$aspect.id[all.GO$aspect==aspect]))
    n.aspects <- length(aspect.ids)
    
    # Given by analyze.GO
    # [1] "aspect"        "aspect.id"     "desc"          "odds"          "P"            
	# [6] "AnnTarg"       "NotAnnTarg"    "AnnNotTarg"    "NotAnnNotTarg"

    res <- data.frame(aspect = rep('', n.aspects), aspect.id = rep(NA, n.aspects), desc = rep('', n.aspects), odds = rep(NA, n.aspects), P = rep(NA, n.aspects), AnnTarg = rep(NA, n.aspects), NotAnnTarg = rep(NA, n.aspects), AnnNotTarg = rep(NA, n.aspects), NotAnnNotTarg = rep(NA, n.aspects), stringsAsFactors = FALSE)
    
    for(i in 1:n.aspects){
    	res[i, ] <- analyze.GO(ids=ids, aspect = aspect, aspect.id = aspect.ids[i], print.all = FALSE)
    }
    res <- res[order(res$P), ]
    res <- data.frame(res, Q = p.adjust(p=res$P, method = "fdr"), stringsAsFactors = FALSE)
    if(!is.null(only.FDR.le)){
    		res <- res[res$Q <= only.FDR.le, ]
    }
    res
}
