get.GO.terms.by.desc <-
function(..., only.aspect=NULL) {
	# get.GO.terms.by.desc
	# Look for GO containing the terms in the input
	# into all.GO$GO.desc
	
	# If only.aspect=NULL it looks in all three aspects:
	# c("BP", "CC", "MF"), otherwise if no-null must be one of those
	# and the search is restricted to that aspect.
	
	# input must be a character vector.
	# If there are no all.GO$GO.desc with the terms specified
	# the function returns "NULL".
	
	# SEE: 356_UsingSALSA [Wed Oct 21 06:23:05 2020]
	
	if(!is.null(only.aspect)){
		if(!is.element(only.aspect, c("BP", "CC", "MF"))) stop("Aspect must be BP = Biological Process or CC = Cell Component or MF = Molecular Function.")
		all.GO.c <- all.GO[all.GO$aspect==only.aspect, ]
	} else {
		all.GO.c <- all.GO
	}
	
	# Get all terms pass:
	look.for <- unlist(list(...))

	n.terms <- length(look.for)
	
	# Begins search (check terms)
	for(i in 1:n.terms){
		if(class(look.for[i])!="character") stop(paste("Term", i, "in the input is not character."))
		all.GO.c <- all.GO.c[grep(look.for[i], all.GO.c$GO.desc, fixed=TRUE), ]
		if(nrow(all.GO.c)==0) return(NULL)
	}
	all.GO.c
}
