get.SEP <-
function (ids = NULL, descr = NULL, acc.key = NULL, acc.type = NULL, 
    model = NULL, ExistInAll = NULL, TimeMaxExp = NULL, isTF = NULL, 
    coded.expr.level = NULL, previous.sep = NULL) 
{
    if ((is.null(ids) * is.null(descr) * is.null(acc.key) * is.null(acc.type) * 
        is.null(model) * is.null(ExistInAll) * is.null(TimeMaxExp) * 
        is.null(isTF) * is.null(coded.expr.level)) == 1) 
        stop("You need at least one criterion not null to proceed!")
    if (is.null(previous.sep)) {
        SEP.c <- SEP
    }
    else {
        SEP.c <- previous.sep
        if (class(SEP.c) != "data.frame") 
            stop("previous.sep must be a valid SEP data.frame!")
        if (prod(names(SEP.c) == names(SEP)) != 1) 
            stop("previous.sep must be a valid SEP data.frame!")
    }
    res <- sort(unique(SEP.c$id))
    if (!is.null(ids)) {
        if ((class(ids) != "numeric") & (class(ids) != "integer")) {
            stop("\n\"ids\" must be a numeric value or vector!")
        }
        if (length(setdiff(ids, res)) > 0) 
            stop("\nOne or more values in \"ids\" do not exist in SEP!")
        SEP.c <- SEP.c[is.element(SEP.c$id, ids), ]
    }
    if (!is.null(descr)) {
        if (class(descr) != "character") 
            stop("\n\"descr\" must be a character vector!")
        for (i in 1:length(descr)) {
            res <- intersect(res, gene$id[grepl(descr[i], gene$Prot.Desc)])
            if (length(res) == 0) {
                return(NULL)
            }
        }
        SEP.c <- SEP.c[is.element(SEP.c$id, res), ]
        res <- sort(unique(SEP.c$id))
        if (length(res) == 0) 
            return(NULL)
    }
    if (!is.null(isTF)) {
        if (class(isTF) != "logical") 
            stop("\n\"isTF\" must be a logic value (TRUE or FALSE)!")
        if (length(isTF) != 1) 
            stop("\n\"isTF\" must have length one (TRUE or FALSE)!")
        res <- intersect(res, gene$id[gene$isTF == isTF])
        SEP.c <- SEP.c[is.element(SEP.c$id, res), ]
        res <- sort(unique(SEP.c$id))
    }
    if (!is.null(ExistInAll)) {
        if (class(ExistInAll) != "logical") 
            stop("\n\"ExistInAll\" must be a logic value (TRUE or FALSE)!")
        if (length(ExistInAll) != 1) 
            stop("\n\"ExistInAll\" must have length one (TRUE or FALSE)!")
        res <- intersect(res, SEP.c$id[SEP.c$ExistInAll == ExistInAll])
        SEP.c <- SEP.c[is.element(SEP.c$id, res), ]
        res <- sort(unique(SEP.c$id))
        if (length(res) == 0) {
            return(NULL)
        }
    }
    if (!is.null(acc.key)) {
        if (class(acc.key) != "character") 
            stop("\n\"acc.key\" must be a character value or vector!")
        if (length(setdiff(acc.key, acc$acc.key)) > 0) 
            stop("\n\"acc.key\" contains a non valid acc.key!")
        acc.key <- unique(acc.key)
        n.acc <- length(acc.key)
        if (n.acc == 1) {
            SEP.c <- SEP.c[SEP.c$acc.key == acc.key, ]
            res <- sort(unique(SEP.c$id))
        }
        else {
            SEPs.acc <- vector("list", n.acc)
            for (i in 1:n.acc) {
                SEPs.acc[[i]] <- SEP.c[SEP.c$acc.key == acc.key[i], 
                  ]
            }
            SEP.c <- Reduce(rbind, SEPs.acc)
            res <- sort(unique(SEP.c$id))
        }
        if (length(res) == 0) {
            return(NULL)
        }
    }
    if (!is.null(acc.type)) {
        if (class(acc.type) != "character") 
            stop("\n\"acc.type\" must be a character value or vector!")
        if (length(setdiff(acc.type, acc$acc.type)) > 0) 
            stop("\n\"acc.type\" contains a non valid acc.type!")
        acc.type <- unique(acc.type)
        n.type <- length(acc.type)
        if (n.type == 1) {
            SEP.c <- SEP.c[SEP.c$acc.type == acc.type, ]
            res <- sort(unique(SEP.c$id))
        }
        else {
            SEPs.acc <- vector("list", n.type)
            for (i in 1:n.type) {
                SEPs.acc[[i]] <- SEP.c[SEP.c$acc.type == acc.type[i], 
                  ]
            }
            SEP.c <- Reduce(rbind, SEPs.acc)
            res <- sort(unique(SEP.c$id))
        }
        if (length(res) == 0) {
            return(NULL)
        }
    }
    if (!is.null(model)) {
        if (class(model) != "character") 
            stop("\n\"model\" must be a character value or vector!")
        all.models <- unique(SEP$model)
        if (length(setdiff(model, all.models)) > 0) 
            stop("\n\"model\" contains a non valid model!")
        model <- unique(model)
        n.mod <- length(model)
        if (n.mod == 1) {
            SEP.c <- SEP.c[SEP.c$model == model, ]
            res <- sort(unique(SEP.c$id))
        }
        else {
            SEPs.acc <- vector("list", n.mod)
            for (i in 1:n.mod) {
                SEPs.acc[[i]] <- SEP.c[SEP.c$model == model[i], 
                  ]
            }
            SEP.c <- Reduce(rbind, SEPs.acc)
            res <- sort(unique(SEP.c$id))
        }
        if (length(res) == 0) {
            return(NULL)
        }
    }
    if (!is.null(TimeMaxExp)) {
        if ((class(TimeMaxExp) != "integer") & (class(TimeMaxExp) != 
            "numeric")) 
            stop("\n\"TimeMaxExp\" must be a integer or numeric value or vector!")
        if (length(setdiff(TimeMaxExp, DAA)) > 0) 
            stop("\n\"TimeMaxExp\" contains a non valid Time of Maximum Expression!")
        TimeMaxExp <- unique(TimeMaxExp)
        n.tme <- length(TimeMaxExp)
        if (n.tme == 1) {
            SEP.c <- SEP.c[SEP.c$TimeMaxExp == TimeMaxExp, ]
            res <- sort(unique(SEP.c$id))
        }
        else {
            SEPs.acc <- vector("list", n.tme)
            for (i in 1:n.tme) {
                SEPs.acc[[i]] <- SEP.c[SEP.c$TimeMaxExp == TimeMaxExp[i], 
                  ]
            }
            SEP.c <- Reduce(rbind, SEPs.acc)
            res <- sort(unique(SEP.c$id))
        }
        if (length(res) == 0) {
            return(NULL)
        }
    }
    if (!is.null(coded.expr.level)) {
        if ((class(coded.expr.level) != "integer") & (class(coded.expr.level) != 
            "numeric")) 
            stop("\n\"coded.expr.level\" must be a integer or numeric value or vector!")
        if (length(setdiff(coded.expr.level, c(1:5))) > 0) 
            stop("\n\"coded.expr.level\" contains a non valid coded expression level")
        coded.expr.level <- unique(coded.expr.level)
        n.cel <- length(coded.expr.level)
        FPKM.expr.c <- FPKM.expr$coded.expr.level[(is.element(FPKM.expr$id, 
            SEP.c$id)) & (is.element(FPKM.expr$acc.key, SEP.c$acc.key)) & 
            (is.element(FPKM.expr$acc.type, SEP.c$acc.type)) & 
            (is.element(FPKM.expr$model, SEP.c$model)) & (is.element(FPKM.expr$ExistInAll, 
            SEP.c$ExistInAll))]
        SEP.c.rows <- c(1:nrow(SEP.c))
        SEP.c <- SEP.c[SEP.c.rows[is.element(FPKM.expr.c, coded.expr.level)], 
            ]
        res <- nrow(SEP.c)
        if (res == 0) {
            return(NULL)
        }
    }
    SEP.c
}
