\name{FPKM.expr}
\alias{FPKM.expr}
\docType{data}
\title{
Expression data per accession and time in FPKM units
}
\description{
Contains mean expression data for each gene (\code{id}) and each accession (\code{acc.key}) at each one of the seven times sampled (\code{mT00} to \code{mT60}) in FPKM (fragments per kilobase of exon model per million reads mapped).
}
\usage{data("FPKM.expr")}
\format{
  A data frame with 313919 observations on the following 14 variables.
  \describe{
    \item{\code{id}}{a numeric vector; gene numeric identifier.}
    \item{\code{acc.key}}{a character vector; two letters code for accessions.}
    \item{\code{acc.type}}{a character vector; D = Domesticated, W = Wild.}
    \item{\code{model}}{a character vector; six letters code for the expression model (see details).}
    \item{\code{ExistInAll}}{a logic; If TRUE the gene was expressed in all 12 accessions.}
    \item{\code{mT00}}{a numeric vector; FPKM expression at 0 DAA.}
    \item{\code{mT10}}{a numeric vector; FPKM expression at 10 DAA.}
    \item{\code{mT20}}{a numeric vector; FPKM expression at 20 DAA.}
    \item{\code{mT30}}{a numeric vector; FPKM expression at 30 DAA.}
    \item{\code{mT40}}{a numeric vector; FPKM expression at 40 DAA.}
    \item{\code{mT50}}{a numeric vector; FPKM expression at 50 DAA.}
    \item{\code{mT60}}{a numeric vector; FPKM expression at 60 DAA.}
    \item{\code{mean.over.time}}{a numeric vector; mean over times of gene expression.}
    \item{\code{coded.expr.level}}{a numeric vector; code for expression levels, see details.}
  }
}
\details{
FPKM (fragments per kilobase of exon model per million reads mapped) is a normalised estimation of gene expression based on RNA-seq data.
Column \code{model} is formed by all the 729 permutations of the letters D, S, I, meaning that the expression in the corresponding interval was Decreasing, Steady or Increasing, respectively.
Column \code{coded.expr.level} codes mean expression level with the following meaning: 1 expression less or equal to 1 FPKM, 2 more than 1 but less than 10 FPKM, 3 more than 10 but less than 100 FPKM, 4 more than 100 but less than 1000 FPKM and 5 more than 1000 FPKM.
}
\source{
Cinvestav Irapuato, Mexico.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\examples{
# A random row of the data.frame
FPKM.expr[sample(c(1:nrow(FPKM.expr)), size=1), ]
# A gene with high expression level (an average expression larger than 1000 FPKM)
head(FPKM.expr[FPKM.expr$coded.expr.level==5,], 1)
# What is codded by this gene?
gene[gene$id==102, ]
# Plot of the expression of gene with 
# id=102 in accession "AS"
plot(DAA, FPKM.expr[(FPKM.expr$id==102)&(FPKM.expr$acc.key=="AS"), 6:12], type="b", ylab="Expression in FPKM", col="red")
# A line marking the mean expression.
abline(h=2413.108, col="grey")
}
\keyword{datasets}
