\name{SEP}
\alias{SEP}
\docType{data}
\title{
Standardized Expression Profile (SEP)
}
\description{
For each gene expressed in each one of the 12 accessions this data frame gives the Standardized Expression Profiles (SEP) as well as auxiliary variables.
}
\usage{data("SEP")}
\format{
  A data frame with 313919 observations on the following 13 variables.
  \describe{
    \item{\code{id}}{a numeric vector; gene identifier.}
    \item{\code{acc.key}}{a character vector; accession identifier.}
    \item{\code{acc.type}}{a character vector; accession type identifier.}
    \item{\code{model}}{a character vector; each value consist of six concatenated letters which for each one of the 6 consecutive intervals are D if the expression decremented, S if the expression was steady, I if the expression incremented.}
    \item{\code{ExistInAll}}{a logic vector; TRUE if the gene ({id}) was expressed in all 12 accessions.}
    \item{\code{seT0}}{a numeric vector; mean expression at time 0.}
    \item{\code{seT10}}{a numeric vector; mean expression at time 10.}
    \item{\code{seT20}}{a numeric vector; mean expression at time 20.}
    \item{\code{seT30}}{a numeric vector; mean expression at time 30.}
    \item{\code{seT40}}{a numeric vector; mean expression at time 40.}
    \item{\code{seT50}}{a numeric vector; mean expression at time 50.}
    \item{\code{seT60}}{a numeric vector; mean expression at time 60.}
    \item{\code{TimeMaxExp}}{a numeric vector; time at which the maximum expression over time was reached.}
  }
}
\details{
SEPs are standardized over time, thus the mean value of each vector is equal to zero while its standard deviation (S) is equal to one.
}
\source{
Cinvestav Irapuato, Mexico.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\examples{
# A random row of the data.frame
SEP[sample(c(1:nrow(SEP)), size=1), ]

# Structure of the dataset
str(SEP)

# Number of SEPs that exist in only some or all accessions.
table(SEP$ExistInAll)

# Summary of numeric variables in SEP
summary(SEP[,6:13])
}
\keyword{datasets}
