\name{SEP.id}
\alias{SEP.id}
\docType{data}
\title{
Summaries of SEP for each gene expressed
}
\description{
For each gene expressed this data.frame presents the number of SEPs per group of accessions where the gene was expressed, general mean SEPs as well as mean SEPs per group of accessions (D = Domesticated, W = Wild and C = Crosses). Includes mean correlation coefficients for SEPs in the whole set of SEPs for each gene, and in the SEPs of each group. Finally, it includes the mean and standard deviation (S) for the time at which the maximum expression of the gene was reached for the total, D, W and C groups. Function {gene.summary} gives a summary of the data in this {data.frame} per gene id.
}
\usage{data("SEP.id")}
\format{
  A data frame with 29946 observations on the following 45 variables.
  \describe{
    \item{\code{id}}{a numeric vector of gene identifiers.}
    \item{\code{n.t}}{a numeric vector with the total number of accessions where the gene was expressed.}
    \item{\code{n.D}}{a numeric vector with the number of D (domesticated) accessions where the gene was expressed.}
    \item{\code{n.W}}{a numeric vector with the number of W (wild) accessions where the gene was expressed.}
    \item{\code{n.C}}{a numeric vector with the number of C (crosses) where the gene was expressed.}
    \item{\code{t.mT0}}{a numeric vector; mean at time 0 in the whole set of SEPs.}
    \item{\code{t.mT10}}{a numeric vector; mean at time 10 in the whole set of SEPs.}
    \item{\code{t.mT20}}{a numeric vector; mean at time 20 in the whole set of SEPs.}
    \item{\code{t.mT30}}{a numeric vector; mean at time 30 in the whole set of SEPs.}
    \item{\code{t.mT40}}{a numeric vector; mean at time 40 in the whole set of SEPs.}
    \item{\code{t.mT50}}{a numeric vector; mean at time 50 in the whole set of SEPs.}
    \item{\code{t.mT60}}{a numeric vector; mean at time 60 in the whole set of SEPs.}
    \item{\code{D.mT0}}{a numeric vector; mean at time 0 in the D set of SEPs.}
    \item{\code{D.mT10}}{a numeric vector; mean at time 10 in the D set of SEPs.}
    \item{\code{D.mT20}}{a numeric vector; mean at time 20 in the D set of SEPs.}
    \item{\code{D.mT30}}{a numeric vector; mean at time 30 in the D set of SEPs.}
    \item{\code{D.mT40}}{a numeric vector; mean at time 40 in the D set of SEPs.}
    \item{\code{D.mT50}}{a numeric vector; mean at time 50 in the D set of SEPs.}
    \item{\code{D.mT60}}{a numeric vector; mean at time 60 in the D set of SEPs.}
    \item{\code{W.mT0}}{a numeric vector; mean at time 0 in the W set of SEPs.}
    \item{\code{W.mT10}}{a numeric vector; mean at time 10 in the W set of SEPs.}
    \item{\code{W.mT20}}{a numeric vector; mean at time 20 in the W set of SEPs.}
    \item{\code{W.mT30}}{a numeric vector; mean at time 30 in the W set of SEPs.}
    \item{\code{W.mT40}}{a numeric vector; mean at time 40 in the W set of SEPs.}
    \item{\code{W.mT50}}{a numeric vector; mean at time 50 in the W set of SEPs.}
    \item{\code{W.mT60}}{a numeric vector; mean at time 60 in the W set of SEPs.}
    \item{\code{C.mT0}}{a numeric vector; mean at time 0 in the C set of SEPs.}
    \item{\code{C.mT10}}{a numeric vector; mean at time 10 in the C set of SEPs.}
    \item{\code{C.mT20}}{a numeric vector; mean at time 20 in the C set of SEPs.}
    \item{\code{C.mT30}}{a numeric vector; mean at time 30 in the C set of SEPs.}
    \item{\code{C.mT40}}{a numeric vector; mean at time 40 in the C set of SEPs.}
    \item{\code{C.mT50}}{a numeric vector; mean at time 50 in the C set of SEPs.}
    \item{\code{C.mT60}}{a numeric vector; mean at time 60 in the C set of SEPs.}
    \item{\code{m.r.t}}{a numeric vector; mean correlation between SEPs.}
    \item{\code{m.r.D}}{a numeric vector; mean correlation between SEPs in D.}
    \item{\code{m.r.W}}{a numeric vector; mean correlation between SEPs in W.}
    \item{\code{m.r.C}}{a numeric vector; mean correlation between SEPs in C.}
    \item{\code{m.TME.t}}{a numeric vector; mean of maximum expression time in the whole set.}
    \item{\code{S.TME.t}}{a numeric vector; Stantard deviation of maximum expression time in the whole set.}
    \item{\code{m.TME.D}}{a numeric vector; mean of maximum expression time in the D set.}
    \item{\code{S.TME.D}}{a numeric vector; Stantard deviation of maximum expression time in the D set.}
    \item{\code{m.TME.W}}{a numeric vector; mean of maximum expression time in the D set.}
    \item{\code{S.TME.W}}{a numeric vector; Stantard deviation of maximum expression time in the W set.}
    \item{\code{m.TME.C}}{a numeric vector; mean of maximum expression time in the C set.}
    \item{\code{S.TME.C}}{a numeric vector; Stantard deviation of maximum expression time in the C set.}
  }
}
\details{
\code{NA} values are present where the corresponding value could not be estimated.
}
\source{
Cinvestav Irapuato, Mexico
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\examples{
# A random row of the data.frame
SEP.id[sample(c(1:nrow(SEP.id)), size=1), ]

# Table with the number of SEPs in the whole (total) set.
table(SEP.id$n.t)

# Plot of mean SEPs per group.
plot(DAA, apply(SEP.id[SEP.id$n.t==12, 6:12], 2, mean), ylim=c(-0.43, 0.25), type="b", ylab="Mean Standaridzed Expression", main="Data for SEPs of 22374 genes", sub="(genes expressed in all 12 accessions)")
points(DAA, apply(SEP.id[SEP.id$n.D==6, 13:19], 2, mean), type="b", col="red")
points(DAA, apply(SEP.id[SEP.id$n.W==4, 20:26], 2, mean), type="b", col="blue")
points(DAA, apply(SEP.id[SEP.id$n.C==2, 27:33], 2, mean), type="b", col="violet")
legend("topright", legend=c("Total", "D", "W", "C"), pch=1, lty=1, col=c("black", "red",  "blue", "violet"))
}
\keyword{datasets}
