\name{SEP.summary}
\alias{SEP.summary}
\title{
Summary of one or many SEPs
}
\description{
Gives a comprehensive summary for the content of one or more Standardized Expression Profile (SEPs) \code{data.frames}. The output is a list with four components containing general statistics, means per expression time, lower limit of the confidence interval for the means and upper limit of the confidence interval for the means, respectively. For each one of the SEPs in the input, one row is produced in each one of the rows of the output \code{data.frame}.
}
\usage{
SEP.summary(..., conf.level = 0.95)
}
\arguments{
  \item{\dots}{
One or more SEPs.
}
  \item{conf.level}{
Confidence Level for the calculation of Confidence Intervals for the mean expression.
}
}
\details{
The order of the rows in the results is the order at which each SEP was set in the input. The \code{t.test} function is used to obtain the Confidence Intervals for the mean expression at each one of the 7 times sampled. If the expression at one or more time points are uniform, the Confidence Interval limits for the mean expression at those points are set equal to the mean at those points, avoiding errors. For SEPs with only one row, CIs (\code{LL.time.means} and \code{UL.time.means}) are set equal to the value of the corresponding mean and a warning is shown in the output.
}
\value{
A \code{list} with four components: \code{general} \code{time.means} \code{LL.time.means} and \code{UL.time.means}. For each SEP in the input, one row is produced in each one of the four components. The order of the rows in the four components of the output corresponds to the order of the SEPs in the input.
\item{general }{\code{data.frame} with columns \code{n.rows} Number of rows in the SEP,
\code{n.ids} Number of different gene identifiers in the SEP,
\code{n.acc} Number of different accession keys in the SEP,
\code{n.type} Number of different accession types in the SEP,
\code{n.mod} Number of different models in the SEP,
\code{mean.TimeMaxExp} Mean time of maximum expression for SEPs,
\code{LL.TimeMaxExp} Lower Limit for the Mean time of maximum expression for SEPs,
\code{UL.TimeMaxExp} Upper Limit for the Mean time of maximum expression for SEPs.}
\item{time.means }{\code{data.frame} with seven columns corresponding to the mean expression at each one of the times sampled, from \code{m.T0} up to \code{m.T60}.}
\item{LL.time.means }{\code{data.frame} with seven columns corresponding to the lower limits for the mean expression at each one of the times sampled, from \code{LL.m.T0} up to \code{LL.m.T60}.}
\item{UL.time.means }{\code{data.frame} with seven columns corresponding to the upper limits for the mean expression at each one of the times sampled, from \code{UL.m.T0} up to \code{UL.m.T60}.}
Each one of the rows in each one of the components corresponds to one of the SEPs in the input, in the same order; i.e., the first row corresponds to to first SEP in the input, the second row corresponds to the second SEP in the input, etc.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
The output gives a summary of the content of each SEP and is used to plot the mean expression of SEPs with their confidence levels at each time, allowing the judgment of significance of differences per time.
}
\seealso{
\code{\link{SEP}}, \code{\link{get.SEP}}, \code{\link{SEP.id}}, \code{\link{SEPs.plot}}, \code{\link{analyze.2.SEPs}}. 
}
\examples{
# Summary of a SEP with a single gene (id)
SEP.summary(get.SEP(ids=3))

# Summary of a SEP with many ids
# (all genes that are Transcription Factors)
SEP.summary(get.SEP(isTF=TRUE))

# Summary of three different SEPs
# (each one containing all Transcription Factors
# in each one of the three acc.type)
SEP.summary(get.SEP(acc.type="D", isTF=TRUE), 
get.SEP(acc.type="W", isTF=TRUE), 
get.SEP(acc.type="C", isTF=TRUE))

# Summary in a case where all expression values
# at each time are the same (and thus confidence
# intervals are set to be equal to the means)
SEP.summary(get.SEP(model="DSSSSS"))
}
