\name{SEPs.plot}
\alias{SEPs.plot}
\title{
Plot mean expression times in SEPs
}
\description{
For one or more SEPs produces a plot of the means of standardized expression at each one of the times sampled, including their confidence intervals.
}
\usage{
SEPs.plot(seps, colors, lwd = 2, conf.level = 0.95, CIs.sep = 0.5)
}

\arguments{
  \item{seps}{
Either, a single SEP or a \code{list} of two or more SEPs.
}
  \item{colors}{
A single color in the case when \code{seps} is a single SEP, or a vector of colors with the same number of colors than the number of \code{seps} passed on that \code{list}. Any valid code for \code{col} (color) is accepted.
}
  \item{lwd}{
Line width.
}
  \item{conf.level}{
Confidence Level for the estimation of the Confidence Intervals for the means at each one of the times.
}
  \item{CIs.sep}{
A value to avoid the overlapping of Confidence Intervals in the X axis. The default of 0.5 days works well in most cases.
}
}
\details{
It is very important that if two or more SEPs are pass to this function, the groups of SEPs must be defined as a \code{list}. Otherwise an unexpected error will be produced. If the expression at one or more time points are uniform, the Confidence Interval limits for the mean expression at those points are set equal to the mean at those points, avoiding errors. In cases of SEPs with only one row CIs are not shown (it is not posible to estimate such CIs).
}
\value{
\code{NULL} (the function is used by its side effect, i.e., to produce a plot of SEPs).
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
Confidence Intervals for the means are shown as thin vertical lines. It is not wise to produce plots with more than a few SEPs, say a maximum of five. Plots with more SEPs will be difficult to interpret.
}
\seealso{
\code{\link{SEP.summary}}, \code{\link{get.SEP}}, \code{\link{SEP.id}}, \code{\link{SEPs.plot}}, \code{\link{analyze.2.SEPs}}.
}
\examples{
# Plot of a single SEP
temp.sep.3 <- get.SEP(ids=3)
SEPs.plot(seps=temp.sep.3, colors="grey")

# Obtaining SEPs per acc.type
temp.sep.3.D <- get.SEP(ids=3, acc.type="D")
temp.sep.3.W <- get.SEP(ids=3, acc.type="W")
temp.sep.3.C <- get.SEP(ids=3, acc.type="C")

# and plotting them together
# Note: in that case argument seps
# MUST be a list!
SEPs.plot(seps=list(temp.sep.3, temp.sep.3.D, 
temp.sep.3.W, temp.sep.3.C),
colors=c("grey", "red", "blue", "violet"))

# Clean temporary objects
rm(list=ls(patt="temp.sep.3"))

# Plot SEPs for two different genes
SEPs.plot(seps=list(get.SEP(ids=3), get.SEP(ids=19)), colors=c("red", "blue"))

# Plot of SEPs with all transcription
# factors group by acc.type
SEPs.plot(seps=list(get.SEP(acc.type="D", isTF=TRUE), 
get.SEP(acc.type="W", isTF=TRUE), 
get.SEP(acc.type="C", isTF=TRUE)), 
colors=c("red", "blue", "violet"))
}
