\name{Salsa-package}
\alias{Salsa-package}
\alias{Salsa}
\docType{package}
\title{
\packageTitle{Salsa}
}
\description{
\packageDescription{Salsa}
}
\details{

The DESCRIPTION file:
\packageDESCRIPTION{Salsa}
\packageIndices{Salsa}
}
\author{
\packageAuthor{Salsa}

Maintainer: \packageMaintainer{Salsa}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\keyword{ package }
\examples{
## Assume that the interest is on genes
# of Transcription Factors (TF) in two accessions
# "CM" (Domesticated) and "QU" (Wild)
# Isolate SEPs with the genes of interest
temp.TF.CM <- get.SEP(acc.key="CM", isTF=TRUE)
temp.TF.QU <- get.SEP(acc.key="QU", isTF=TRUE)
temp.TF.CM.QU <- get.SEP(acc.key=c("CM", "QU"), isTF=TRUE)

# Obtain a summary of the content of the
# three SEPs
SEP.summary(temp.TF.CM.QU, temp.TF.CM,
temp.TF.QU, conf.level=0.99)

# Plot the corresponding SEPs to have an idea
# of mean expression per time (DAA)
SEPs.plot(list(temp.TF.CM.QU, temp.TF.CM, 
temp.TF.QU), colors=c("grey", "red", "blue"), 
conf.level=0.99)
title(main="Transcription Factors in QU and CM") 
legend("topright", legend=c("CM and QU", "CM", "QU"), 
col=c("grey", "red", "blue"), pch=1, lwd=2)

# Using the previously Isolated SEPs of all
# TFs, Isolate only the ones that have "GATA"
# in their description
temp.GATA.CM <- get.SEP(descr="GATA", previous.sep=temp.TF.CM)
temp.GATA.QU <- get.SEP(descr="GATA", previous.sep=temp.TF.QU)

# Perform a test of Euclidean distances between
# SEPs of GATA TFs in accessions CM and QU
analyze.2.SEPs(temp.GATA.CM, temp.GATA.QU, conf.level=0.99)

# Clean the temporal objects created
rm(list=c(ls(patt="temp.TF"), ls(patt="temp.GATA")))

# Obtain the gene ids of all
# GATA TFs which are expressed
# in all 12 accessions
ids.GATA <- get.ids(descr="GATA", ExistInAll=TRUE, isTF=TRUE)
length(ids.GATA)

# Look for GO terms of aspect BP
# which contain "cell cycle",
# "negative regulation", and "mitotic"
# within their description.
get.GO.terms.by.desc("cell cycle", 
"negative regulation", 
"mitotic", only.aspect="BP")

# Now perform a GO enrichment
# analysis having as target the
# genes in "ids.GATA"
analyze.GO(ids.GATA, aspect="BP", aspect.id=1814)

# See two of the descriptions of the
# GATA TFs in the gene data.frame.
head(gene[is.element(gene$id, ids.GATA), ], 2)

# Remove the temp object
rm("ids.GATA")

# Finally browse in NCBI the data about
# the first one of these two genes.
browse.gene(ProtId="XP_016577838.1")

# Also browse in GO the meaning of the
# GO term "GO:0045930"
# (previously analyzed)
browse.GO(GO="GO:0045930")
}
