\name{analyze.2.SEPs}
\alias{analyze.2.SEPs}
\title{
Test two SEPs trough Euclidean distances
}
\description{
Mean Euclidean distances within and between the two SEPs are tested via the t-test to decide if there is a global difference in the expression profiles contained within the two sets of SEPs. Null hypothesis is that the mean distances within and between SEPs are equal, while the one-tail alternative hypothesis is that the mean distance between SEPs is larger than the mean distance within SEPs. This last possibility implies that the two SEPs are globally different.
}
\usage{
analyze.2.SEPs(sep1, sep2, conf.level = 0.95, do.print = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{sep1}{
A SEP \code{data.frame} obtained with the function \code{get.SEP}
}
  \item{sep2}{
A SEP \code{data.frame} obtained with the function \code{get.SEP}
}
  \item{conf.level}{
Confidence level to perform the \code{t-test}
}
  \item{do.print}{
\code{logical}. If \code{TRUE} the function prints the results, otherwise invisible returns a \code{data.frame} with main results
}
}
\details{
Let's \code{n1} and \code{n2} be the number of rows of \code{sep1} and \code{sep2}, respectively. Then the number of distances within SEPs is given by \code{(n1*(n1-1/2)) + (n2*(n2-1/2))}, while the number of distances between SEPs is given by \code{n1*n2}.
}
\value{
The function prints results of the t-test if \code{do.print = TRUE} and invisible returns a numeric vactor with named components
\item{n.sep1 }{Number of SEPs in sep1}
\item{n.sep2 }{Number of SEPs in sep2}
\item{t.value }{Value of the t statistic}
\item{df }{Degrees of freedom for the test}
\item{p-value }{P value reached by the test}
\item{conf.level }{Confidence level}
\item{L.CL }{Lower Confidence Limit of the Confidence Interval}
\item{mean.dis.bet }{Mean distance between SEPs}
\item{mean.dis.wit }{Mean distance within SEPs}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
This univariate test solves the problem of performing multiple tests (one for each one of the seven time points sampled), but is sensitive to outliers.
}
\seealso{
\code{\link{get.SEP}}, \code{\link{SEP.summary}}. 
}
\examples{
# SEPs of gene with id=3 in "D" versus
# SEPs of gene with id=3 in "W" or "C"
analyze.2.SEPs(sep1=get.SEP(id=3, acc.type="D"), 
sep2=get.SEP(id=3, acc.type=c("W", "C")))

# Test of SEPs for two different genes
analyze.2.SEPs(sep1=get.SEP(id=3), 
sep2=get.SEP(id=19))
}
