\name{analyze.GO}
\alias{analyze.GO}
\title{
GO enrichment analysis
}
\description{
Performs a GO enrichment analysis for a set of genes identified by their ids. The analysis is performed using the Fisher's exact test.
}
\usage{
analyze.GO(ids, aspect, aspect.id, print.all = TRUE)
}
\arguments{
  \item{ids}{
(\code{numeric}) Set of target gene identifiers to form the 2 x 2 contingency table to be tested. 
}
  \item{aspect}{
Must be one of the valid aspects of GO: "BP" (Biological Process) or "CC" (Cell Component) or "MF" (Molecular function).
}
  \item{aspect.id}{
Numeric identifier of the aspect.
}
  \item{print.all}{
\code{logic}; \code{TRUE} will print the results, \code{FALSE} will only invisibly return the results.
}
}
\details{
A contingency table is formed by crossing the criteria Annotated and Target (in each case FALSE or TRUE) and the resulting 2 x 2 contingency table is analyzed using Fisher's exact test under the null hypothesis of criteria independence. By default results are printed by the function and a data.frame with the results is invisibly returned.
}
\value{
A data.frame with the following columns
\item{aspect }{GO aspect analyzed.}
\item{aspect.id }{Numerical identifier of the GO aspect.}
\item{desc }{Description of the GO aspect analyzed.}
\item{odds }{Odds ratio for the contingency table.}
\item{P }{P value for the test of independence.}
\item{AnnTarg }{Annotated with aspect and in Target set}
\item{NotAnnTarg }{Not Annotated with aspect and in Target set}
\item{AnnNotTarg }{Annotated with aspect and Not in Target set}
\item{NotAnnNotTarg }{Not Annotated with aspect and Not in Target set}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
The total of genes taken into account corresponds to the total of genes with valid expression in the data and which are annotated in the GO aspect.
}
\seealso{
\code{\link{analyze.all.GO}}, \code{\link{get.ids}}, \code{\link{get.GO.terms.by.desc}}, \code{\link{browse.GO}}.   
}
\examples{
# An example with the first 1000 gene identifiers
# (a fully arbitraty set)
analyze.GO(ids=gene$id[1:1000])	

# Performs a GO enrichment analysis in
# a set of 100 genes taken at random.
# Also GO aspect and term are random
temp.asp <- sample(c("BP", "CC", "MF"), size=1)
analyze.GO(ids=sample(gene$id, size=100), aspect=temp.asp, aspect.id=sample(all.GO$aspect.id[all.GO$aspect==temp.asp], size=1))
rm(temp.asp)

# Same random experiment but this time
# with 1000 genes
temp.asp <- sample(c("BP", "CC", "MF"), size=1)
analyze.GO(ids=sample(gene$id, size=1000), aspect=temp.asp, aspect.id=sample(all.GO$aspect.id[all.GO$aspect==temp.asp], size=1))
rm(temp.asp)
}