\name{get.GO.terms.by.desc}
\alias{get.GO.terms.by.desc}
\title{
Finds GO terms that fulfill the input
}
\description{
Finds all Gene Ontology (GO) terms that include in their descriptions all words pass to the function in the input.
}
\usage{
get.GO.terms.by.desc(..., only.aspect = NULL)
}
\arguments{
  \item{\dots}{
One or more words (character strings) that must be present in the GO description to be present in the output.
}
  \item{only.aspect}{
If not \code{NULL} it must contain the code for a single GO aspect that you want to look for, say BP = Biological Process, CC = Cell Component or MF = Molecular function.
}
}
\value{
Either, \code{NULL} when the function does not find one or more of the terms pass in the input, of a \code{data.frame} with columns
\item{aspect }{GO aspect}
\item{aspect.id }{Numeric identifier of the GO term within aspect}
\item{GO }{GO identifier}
\item{GO.desc }{GO descrioption}
In this \code{data.frame} all cases of \code{GO.desc} include all terms pass to the function in the input.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\seealso{
\code{\link{get.genes.by.GO.desc}}, \code{\link{all.GO}}, \code{\link{analyze.GO}}, \code{\link{browse.GO}}, \code{\link{GO.annot}}.
}
\examples{
# When the functio does not find
# the term pass in the input:
get.genes.by.GO.desc("My favorite GO term")

# Obtains a set of GO terms which includes
# "mitotic cell cycle" in their description
# Show just the first two of them
head(get.GO.terms.by.desc("mitotic cell cycle"),2)
# How many of those?
nrow(get.GO.terms.by.desc("mitotic cell cycle"))

# A more concise search
# (asking for two terms)
get.GO.terms.by.desc("mitotic cell cycle", 
"negative regulation")

# Using a specific aspect
# (only.aspect "BP", "MF" or "CC")
get.GO.terms.by.desc("wall", only.aspect="CC")
get.GO.terms.by.desc("wall", only.aspect="MF")
}
