gene.summary <-
function(id=3, leg.pos="topright", T.col="grey", D.col="red", W.col="blue", C.col="violet"){
	# gene.summary from SEP.id
	# SEE: 355_Salsa
	
	if(!is.element(id, SEP.id$id)) stop(paste("\nGene with id =", id, "does not exist in SEP.id"))
	res <- as.numeric(SEP.id[SEP.id$id==id, 2:45])
	l.res <- list(paste("id =", id))
	title.main <- gene$Prot.Desc[gene$id==id]
	if(is.na(title.main)) {
		title.main <- ""
		l.res[[1]] <- paste(l.res[[1]], " (No protein description)", sep="")
	} else {
		l.res[[1]] <- paste(l.res[[1]], " (", title.main, ")", sep="")
	}
	cat("\n", l.res[[1]], "\n\nNumber of accessions per group:\n")
	# 1:4 "n.t" "n.D" "n.W" "n.C"
	l.res[[2]] <- res[1:4]
	names(l.res[[2]]) <- c("Total", "D", "W", "C")
	print(l.res[[2]])
	# 5.11 "t.mT0" to "t.mT60"
	# 12.18 "D.mT0" to "D.mT60"
	# 19.25 "W.mT0" to "W.mT60"
	# 26.32 "C.mT0" to "C.mT60"
	# 33.36 "m.r.t" "m.r.D" "m.r.W" "m.r.C"
	l.res[[3]] <- res[33:36]
	names(l.res[[3]]) <- c("m.r.t", "m.r.D", "m.r.W", "m.r.C")
	cat("\nMean correlations per group:\n")
	print(round(l.res[[3]],4))
	# 37.44 m.TME, S.TME in t, D, W, C.
	l.res[[4]] <- matrix(res[37:44], nrow=4, ncol=2, byrow =TRUE, dimnames=list(c("Total", "D", "W", "C"), c("Mean", "S")))
	cat("\nMeans and Standard Deviations (S) for Maximum Expression\n")
	print(round(l.res[[4]], 2))
	the.lim <- c(min(res[5:32], na.rm=TRUE), max(res[5:32], na.rm=TRUE))
	plot(DAA, res[5:11], type="l", col=T.col, lwd=2, ylim=the.lim, xlab="Time (DAA)", ylab="Mean Stanardized Expression", main=title.main, sub=paste("id =", id))
	the.leg <- paste("Total", res[1])
	leg.col <- T.col
	grid()
	if(res[2]>0) {
		points(DAA, res[12:18], type="l", col="red", lwd=2)
		the.leg <- c(the.leg , paste(res[2], "D"))
		leg.col <- c(leg.col, D.col)
		}
	if(res[3]>0) {
		points(DAA, res[19:25], type="l", col="blue", lwd=2)
		the.leg <- c(the.leg , paste(res[3], "W"))
		leg.col <- c(leg.col, W.col)
		}
	if(res[4]>0) {
		points(DAA, res[26:32], type="l", col="violet", lwd=2)
		the.leg <- c(the.leg , paste(res[4], "C"))
		leg.col <- c(leg.col, C.col)
		}
	legend(leg.pos, legend=the.leg, lty=1, lwd=2, col=leg.col)
	names(l.res) <- c("IdDesc","Acc.x.group","Mean.r.x.group","StatMaxExpx.group")

	invisible(l.res)
}
