\name{gene.summary}
\alias{gene.summary}
\title{
Graphic and numeric summary of a gene
}
\description{
Gives a plot as well as a summary of mean standardized expression over time for a gene in the types of accessions where it was expressed (D, W and C).
}
\usage{
gene.summary(id, leg.pos, T.col, D.col, W.col, C.col)
}
\arguments{
  \item{id}{
Identifier of the gene.
}
  \item{leg.pos}{
Possition of the legend in the plot: one of \code{bottomright}, \code{bottom},  \code{bottomleft},  \code{left},  \code{topleft},  \code{top},  \code{topright},  \code{right} and \code{center}.
}
  \item{T.col}{
Color to be used for plotting the expression mean of all accessions.
}
  \item{D.col}{
Color to be used for plotting the expression mean of D accessions.
}
  \item{W.col}{
Color to be used for plotting the expression mean of W accessions.
}
  \item{C.col}{
Color to be used for plotting the expression mean of C accessions.
}
}
\details{
This function is used mainly for its side effect: plotting of mean expression per group and summary of mean expression. But also it invisibly returns a list with the main results of the summary of mean expression.
}
\value{
	Invisibly returns a list with the following components
\item{IdDesc }{Identification of the gene.}
\item{Acc.x.group }{Number of accessions where the gene was expressed (per group).}
\item{Mean.r.x.group }{Mean expression correlation (r) of SEPs within each group.}
\item{StatMaxExpx.group }{A matrix giving the mean and standard deviation (S) for the time at which the maximum expression was reached for each accession group.}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
Octavio Martinez.
}
\note{
The plot and summary is obtained from the data in SEP.id which in turn summarizes the standardized expression profile for each one of the genes.
}
\seealso{
\code{\link{SEP.id}}
}
\examples{
# Summary for the gene with highest mean expression in the dataset
# See: FPKM.expr[FPKM.expr$mean.over.time>17000,]
gene.summary(id = 7975, leg.pos = "topleft")

# Obtains a summary of one gene
# selecting it at random
gene.summary(id=sample(SEP.id$id, size=1))
}
