\name{get.genes.by.GO.desc}
\alias{get.genes.by.GO.desc}
\title{
Select genes annotated with GO terms
}
\description{
Obtains a \code{data.frame} of all genes annotated with one or more Gene Ontology (GO) aspects and terms, returning an informative \code{data.frame}.
}
\usage{
get.genes.by.GO.desc(..., only.aspect = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{\dots}{
One or more character strings that you want to be part of the description of the Gene Ontology term description.
}
  \item{only.aspect}{
If not \code{NULL} it must contain the code for a single GO aspect that you want to look for, say BP = Biological Process, CC = Cell Component or MF = Molecular function.
}
}
\details{
All the character strings pass to the function must be part of one or more GO term descriptions, otherwise a \code{NULL} value is return.
}
\value{
Either, a \code{NULL} value (when there are not GO terms that fulfill the input) or a\code{data.frame} with the following columns:
\item{id }{Gene numeric identifier}
\item{aspect }{GO aspect}
\item{GO }{GO term}
\item{GO.desc }{Description of the GO term}
\item{ProtId }{Identifier of the protein coded by the gene}
\item{Prot.Desc }{Description of the protein coded by the gene}
\item{isTF }{logical; Is the gene annotated as a Transcription Factor}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. MArtinez
}
\note{
The output \code{data.frame} can be redundant, having the same genes various times, depending on how many GO aspects each gene is annotated.
}
\seealso{
\code{\link{get.GO.terms.by.desc}}, \code{\link{all.GO}}, \code{\link{analyze.GO}}, \code{\link{browse.GO}}, \code{\link{GO.annot}}.  
}
\examples{
# A case where the function cannot
# find any gene fulfilling the search
# and thus returns NULL
get.genes.by.GO.desc("my favorite GO term")

# Obtain a set of genes which include
# "mitotic cell cycle" in their GO annotations
# (see only the fist two rows)
head(get.genes.by.GO.desc("mitotic cell cycle"),2)

# How many cases are there?
nrow(get.genes.by.GO.desc("mitotic cell cycle"))
# Note: that one gene can be annotated in
# various of the GO terms:
# How many different genes ("id"s)
length(unique(get.genes.by.GO.desc("mitotic cell cycle")$id))
# How many different GO terms ("id"s)
length(unique(get.genes.by.GO.desc("mitotic cell cycle")$GO))

# Using the only.aspect parameter
nrow(get.genes.by.GO.desc("wall", only.aspect="BP"))
nrow(get.genes.by.GO.desc("wall", only.aspect="CC"))
nrow(get.genes.by.GO.desc("wall", only.aspect="MF"))
}
