\name{get.genes.by.desc}
\alias{get.genes.by.desc}
\title{
Select genes that fulfill a description criteria
}
\description{
Shows the rows of the \code{gene} \code{data.frame} which include into \code{Prot.Desc} the character chains pass to the function.
}
\usage{
get.genes.by.desc(...)
}
\arguments{
  \item{\dots}{
One or more character strings that you want to be part of the \code{Prot.Desc} for the gene.
}
}
\details{
All the character strings pass in the input must be present in the \code{Prot.Desc}, otherwise a \code{NULL} value is returned by the function.
}
\value{
Either, a \code{NULL} value (when there are not \code{Prot.Desc} that fulfill the input) or a subset of the \code{gene} \code{data.frame} which rows in which the \code{Prot.Desc} column includes all terms in the input.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.}
\author{
O. Martinez
}
\note{
For general descriptions the \code{data.frame} returned can be large.
}
\seealso{
\code{\link{gene}}
}
\examples{
# A case where the function cannot
# find a Prot.Desc that fulfills
# the search
get.genes.by.desc("my favorite gene")

# Obtain a subset of genes which includes
# "WRKY" in their description
head(get.genes.by.desc("WRKY"))
# How many of those genes are there?
nrow(get.genes.by.desc("WRKY"))

# Having also ""factor 53"
head(get.genes.by.desc("WRKY", "factor 53"))
# How many of those?
nrow(get.genes.by.desc("WRKY", "factor 53"))

# How many containing "DNA polymerase"
nrow(get.genes.by.desc("DNA polymerase"))

# A more concise search
get.genes.by.desc("DNA polymerase I")
}
